@@ -1,3 +1,5 @@
+# vim:fileencoding=utf-8 
+#
 # greetingInKorean.py
 #
 # Demonstration of the parsing module, on the prototypical "Hello, World!" example
@@ -11,7 +13,8 @@ koreanWord = Word(koreanChars,min=2)
 greet = koreanWord + "," + koreanWord + "!"
 
 # input string
-hello = u'\uc548\ub155, \uc5ec\ub7ec\ubd84!' #"Hello, World!" in Korean
+hello = '\uc548\ub155, \uc5ec\ub7ec\ubd84!' #"Hello, World!" in Korean
 
 # parse input string
-print hello, "->", greet.parseString( hello )
+print(greet.parseString( hello ))
+
